package com.ruoyi.system.service.impl;

import java.util.List;
import com.ruoyi.common.utils.DateUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.ruoyi.system.mapper.HyperlinkMapper;
import com.ruoyi.system.domain.Hyperlink;
import com.ruoyi.system.service.IHyperlinkService;

/**
 * 超链接Service业务层处理
 * 
 * @author boman
 * @date 2024-04-30
 */
@Service
public class HyperlinkServiceImpl implements IHyperlinkService 
{
    @Autowired
    private HyperlinkMapper hyperlinkMapper;

    /**
     * 查询超链接
     * 
     * @param hyperlinkId 超链接主键
     * @return 超链接
     */
    @Override
    public Hyperlink selectHyperlinkByHyperlinkId(Long hyperlinkId)
    {
        return hyperlinkMapper.selectHyperlinkByHyperlinkId(hyperlinkId);
    }

    /**
     * 查询超链接列表
     * 
     * @param hyperlink 超链接
     * @return 超链接
     */
    @Override
    public List<Hyperlink> selectHyperlinkList(Hyperlink hyperlink)
    {
        return hyperlinkMapper.selectHyperlinkList(hyperlink);
    }

    /**
     * 新增超链接
     * 
     * @param hyperlink 超链接
     * @return 结果
     */
    @Override
    public int insertHyperlink(Hyperlink hyperlink)
    {
        hyperlink.setCreateTime(DateUtils.getNowDate());
        return hyperlinkMapper.insertHyperlink(hyperlink);
    }

    /**
     * 修改超链接
     * 
     * @param hyperlink 超链接
     * @return 结果
     */
    @Override
    public int updateHyperlink(Hyperlink hyperlink)
    {
        hyperlink.setUpdateTime(DateUtils.getNowDate());
        return hyperlinkMapper.updateHyperlink(hyperlink);
    }

    /**
     * 批量删除超链接
     * 
     * @param hyperlinkIds 需要删除的超链接主键
     * @return 结果
     */
    @Override
    public int deleteHyperlinkByHyperlinkIds(Long[] hyperlinkIds)
    {
        return hyperlinkMapper.deleteHyperlinkByHyperlinkIds(hyperlinkIds);
    }

    /**
     * 删除超链接信息
     * 
     * @param hyperlinkId 超链接主键
     * @return 结果
     */
    @Override
    public int deleteHyperlinkByHyperlinkId(Long hyperlinkId)
    {
        return hyperlinkMapper.deleteHyperlinkByHyperlinkId(hyperlinkId);
    }
}
