package com.ruoyi.system.service.impl;

import java.util.List;

import com.ruoyi.common.utils.SecurityUtils;
import com.ruoyi.common.utils.StringUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.ruoyi.system.domain.SysNotice;
import com.ruoyi.system.mapper.SysNoticeMapper;
import com.ruoyi.system.service.ISysNoticeService;

/**
 * 公告 服务层实现
 *
 * @author ruoyi
 */
@Service
public class SysNoticeServiceImpl implements ISysNoticeService {
    @Autowired
    private SysNoticeMapper noticeMapper;

    /**
     * 查询公告信息
     *
     * @param noticeId 公告ID
     * @return 公告信息
     */
    @Override
    public SysNotice selectNoticeById(Long noticeId) {
        SysNotice sysNotice = noticeMapper.selectNoticeById(noticeId);
        String readUserId = sysNotice.getReadUserId();
        if (StringUtils.isNotEmpty(readUserId)) {
            readUserId = readUserId + "," + SecurityUtils.getUserId();
        } else {
            readUserId = SecurityUtils.getUserId() + "";
        }
        sysNotice.setReadUserId(readUserId);
        noticeMapper.updateNotice(sysNotice);
        return sysNotice;
    }

    /**
     * 查询公告列表
     *
     * @param notice 公告信息
     * @return 公告集合
     */
    @Override
    public List<SysNotice> selectNoticeList(SysNotice notice) {
        Long userId = SecurityUtils.getUserId();
        notice.setIsRead(userId.toString());
        //查询已读或者未读
        List<SysNotice> sysNotices = noticeMapper.selectNoticeList(notice);
        if (sysNotices != null && sysNotices.size() > 0) {
            for (SysNotice sysNotice : sysNotices) {
                String readUserId = sysNotice.getReadUserId();
                //判断是否已读 = readUserId是否包含当前登录人的id
                if (readUserId.contains(String.valueOf(userId))){
                    sysNotice.setIsRead("Y");
                }
            }
        }
        return sysNotices;
    }

    /**
     * 新增公告
     *
     * @param notice 公告信息
     * @return 结果
     */
    @Override
    public int insertNotice(SysNotice notice) {
        return noticeMapper.insertNotice(notice);
    }

    /**
     * 修改公告
     *
     * @param notice 公告信息
     * @return 结果
     */
    @Override
    public int updateNotice(SysNotice notice) {
        return noticeMapper.updateNotice(notice);
    }

    /**
     * 删除公告对象
     *
     * @param noticeId 公告ID
     * @return 结果
     */
    @Override
    public int deleteNoticeById(Long noticeId) {
        return noticeMapper.deleteNoticeById(noticeId);
    }

    /**
     * 批量删除公告信息
     *
     * @param noticeIds 需要删除的公告ID
     * @return 结果
     */
    @Override
    public int deleteNoticeByIds(Long[] noticeIds) {
        return noticeMapper.deleteNoticeByIds(noticeIds);
    }
}
